from datetime import datetime

from ....shared.file_acquisition.dtos.file_acquisition_message import (
    FileAcquisitionMessage,
)
from ....shared.utils.date_util import datetime_to_str, str_to_datetime, utc_now
from ....shared.file_acquisition.models.models import (
    Package,
    DropboxItem,
)

datetime_format = "%Y-%m-%d %H:%M:%S"


class DropboxMessage(FileAcquisitionMessage):
    # Encode (json dumps)
    encode_names = {
        "sha256": "Sha256",
        "sha1": "Sha1",
        "md5": "Md5",
        "name": "Name",
        "date_created": "DateCreated",
        "date_modified": "DateModified",
        "operation": "Operation",
        "status": "Status",
        "message_type": "MessageType",
        "source": "Source",
    }
    encode_settings = {
        "date_created": lambda x: datetime_to_str(x, datetime_format),
        "date_modified": lambda x: datetime_to_str(x, datetime_format),
    }

    decode_names = {v: k for k, v in encode_names.items()}

    # TODO update utc now default
    decode_settings = {
        "date_created": lambda x: utc_now()
        if x is None
        else str_to_datetime(x, datetime_format),
        "date_modified": lambda x: utc_now()
        if x is None
        else str_to_datetime(x, datetime_format),
        "sha256": lambda x: x.lower(),
        "sha1": lambda x: x.lower(),
        "md5": lambda x: x.lower(),
    }

    def __init__(
        self,
        sha256: str = None,
        sha1: str = None,
        md5: str = None,
        name: str = None,
        date_created: datetime = None,
        date_modified: datetime = None,
        message_type: str = None,
        source: str = None,
        operation: str = None,
        status: str = None,
    ):
        self.sha256 = sha256
        self.sha1 = sha1
        self.md5 = md5
        self.name = name
        self.date_created = date_created or utc_now()  # operation date
        self.date_modified = utc_now() or date_modified
        self.message_type = message_type
        self.source = source
        self.operation = operation
        self.status = status

    def get_dropbox_item(self):
        return DropboxItem(
            source_id=self.get_source_id(self.source),
            name=self.name,
            sha256=self.sha256.upper(),
            date_created=self.date_modified,
            date_modified=self.date_modified,
        )

    def get_package(self):
        return Package(
            name=self.name,
            sha256=self.sha256.upper(),
            sha1=self.sha1.upper(),
            md5=self.md5.upper(),
            date_created=self.date_modified,
            date_modified=self.date_modified,
        )
