from datetime import datetime

from ..enums.message_type import StatusUpdateMessageType
from ..enums.operation import StatusUpdateOperation
from ....shared.file_acquisition.dtos.file_acquisition_message import (
    FileAcquisitionMessage,
)
from ....shared.utils.date_util import datetime_to_str, str_to_datetime, utc_now

datetime_format = "%Y-%m-%dT%H:%M:%S"


class ImporterStatusMessage(FileAcquisitionMessage):
    # Encode (json dumps)
    encode_names = {
        "sha256": "Sha256",
        "date_created": "DateCreated",
        "operation": "Operation",
        "status": "Status",
        "message_type": "MessageType",
    }
    encode_settings = {"date_created": lambda x: datetime_to_str(x, datetime_format)}

    decode_names = {v: k for k, v in encode_names.items()}

    decode_settings = {
        "date_created": lambda x: utc_now()
        if x is None
        else str_to_datetime(x[:19], datetime_format),
        "sha256": lambda x: x.lower(),
    }

    def __init__(
        self,
        sha256: str = None,
        status: str = None,
        date_created: datetime = None,
    ):
        self.sha256 = sha256
        self.date_created = date_created or utc_now()  # operation date
        self.message_type = StatusUpdateMessageType.IMPORTER.name
        self.operation = StatusUpdateOperation.IMPORT.name
        self.status = status
