import sys


# Exception chaining
class TICException(Exception):
    def __init__(self, other):
        self.traceback = sys.exc_info()
        super(TICException, self).__init__(other.message)


class RetryableError(Exception):
    def __init__(self, ex, stack_trace):
        self.message = str(ex)
        self.stack_trace = stack_trace
        self.data = []

    def add(self, raw_record):
        self.data.append({"raw_record": raw_record})


class LambdaException(Exception):
    def __init__(self):
        self.data = []

    def __str__(self):
        return "\n\n" + "\n".join(
            [
                f"Exception number: {i}"
                f"\nException Message: {x['exception_message']}"
                f"\nStack Trace: {x['stack_trace']}"
                for i, x in enumerate(self.data)
            ]
        )

    def add(self, message, stack_trace, bad_record, record):
        self.data.append(
            {
                "exception_message": message,
                "stack_trace": stack_trace,
                "bad_record": bad_record,
                "record": record,
            }
        )


class EmptyReportException(Exception):
    def __init__(self, *args):
        super().__init__(*args)


def lambda_raise(e):
    raise e
