import requests
import hashlib
from tic.shared.utils.parsers.hash import HashType


def download_file(
    url, local_filename, verify_server=False, cert_key=None, cert_file=None
):
    r = requests.get(url, stream=True, verify=verify_server, cert=(cert_file, cert_key))
    with open(local_filename, "wb") as f:
        for chunk in r.iter_content(chunk_size=1024):
            if chunk:  # filter out keep-alive new chunks
                f.write(chunk)
                f.flush()


def get_file_hash(file_name, hash_type):
    block_size = 65536

    if hash_type == HashType.md5:
        hasher = hashlib.md5(usedforsecurity=False)
    elif hash_type == HashType.sha1:
        hasher = hashlib.sha1()
    elif hash_type == HashType.sha256:
        hasher = hashlib.sha256()
    elif hash_type == HashType.sha512:
        hasher = hashlib.sha512()
    else:
        raise Exception("The specified hash_type [%s] is invalid" % hash_type)

    with open(file_name, "rb") as f:
        buf = f.read(block_size)
        while len(buf) > 0:
            hasher.update(buf)
            buf = f.read(block_size)

    return hasher.hexdigest()
