# Native imports
import json

from ...utils.util import chunk


def send_to_dlq(
    boto_session, queue_name, records, exception_messages, stack_traces=None
):
    """
    Send items to the DLQ.

    @param boto_session: The session to use for the request.
    @param queue_name: The name of the queue.
    @param records: A dict of the records to send and the associated error message.
    @param stack_traces: The exception stack traces.
    """

    client = boto_session.client("sqs")
    queue_url = client.get_queue_url(QueueName=queue_name)["QueueUrl"]

    for c in chunk(zip(records, exception_messages, stack_traces), 10):
        messages = []
        for i, (record, exception_message, stack_trace) in enumerate(c):
            messages.append(
                {
                    "Id": str(i),
                    "MessageBody": json.dumps(
                        {
                            "exception_message": exception_message,
                            "stack_trace": stack_trace,
                            "record": record,
                        }
                    ),
                }
            )
        client.send_message_batch(QueueUrl=queue_url, Entries=messages)
